function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const coercer = (_ref) => {
  let {
    intValue,
    stringValue,
    bigIntValue
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["intValue", "stringValue", "bigIntValue"]);

  if (intValue != null) {
    return Number(intValue);
  } else if (bigIntValue != null) {
    return Number(bigIntValue);
  } else if (stringValue != null) {
    return String(stringValue);
  } else {
    throw new Error(`Unknown type ${JSON.stringify(rest)}`);
  }
};

const executeSql = async (pool, sql) => {
  const result = await pool.rdsDataService.executeSql({
    awsSecretStoreArn: pool.config.awsSecretStoreArn,
    dbClusterOrInstanceArn: pool.config.dbClusterOrInstanceArn,
    database: pool.config.databaseName,
    sqlStatements: sql
  }).promise();

  if (!Array.isArray(result.sqlStatementResults) || result.sqlStatementResults.length !== 1) {
    return null;
  }

  const firstResult = result.sqlStatementResults[0];

  if (firstResult == null || firstResult.resultFrame == null) {
    return null;
  }

  const {
    resultFrame: {
      records,
      resultSetMetadata
    }
  } = firstResult;

  if (!Array.isArray(records) || resultSetMetadata == null) {
    return null;
  }

  const {
    columnCount,
    columnMetadata
  } = resultSetMetadata;
  const rows = [];

  for (const _ref2 of records) {
    const {
      values
    } = _ref2;
    const row = {};

    for (let i = 0; i < columnCount; i++) {
      row[columnMetadata[i].name] = coercer(values[i]);
    }

    rows.push(row);
  }

  return rows;
};

const connect = async (pool, {
  RDSDataService,
  escapeId,
  escape
}) => {
  const rdsDataService = new RDSDataService({
    region: pool.config.region
  });
  Object.assign(pool, {
    tableName: pool.config.tableName,
    rdsDataService,
    executeSql: executeSql.bind(null, pool),
    escapeId,
    escape,
    resourceOptions: pool.config.resourceOptions
  });
};

export default connect;
//# sourceMappingURL=connect.js.map