"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const loadEvents = async ({
  executeSql,
  escapeId,
  escape,
  tableName
}, {
  eventTypes,
  aggregateIds,
  startTime,
  finishTime,
  maxEventsByTimeframe = Number.POSITIVE_INFINITY
}, callback) => {
  const injectString = value => `${escape(value)}`;

  const injectNumber = value => `${+value}`;

  const batchSize = 50;
  const queryConditions = [];

  if (eventTypes != null) {
    queryConditions.push(`${escapeId('type')} IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    queryConditions.push(`${escapeId('aggregateId')} IN (${aggregateIds.map(injectString)})`);
  }

  if (startTime != null) {
    queryConditions.push(`${escapeId('timestamp')} > ${injectNumber(startTime)}`);
  }

  if (finishTime != null) {
    queryConditions.push(`${escapeId('timestamp')} < ${injectNumber(finishTime)}`);
  }

  const resultQueryCondition = queryConditions.length > 0 ? `WHERE ${queryConditions.join(' AND ')}` : '';
  let initialTimestamp = null;
  let countEvents = 0;

  loop: for (let skipCount = 0;; skipCount++) {
    const rows = await executeSql(`SELECT * FROM ${escapeId(tableName)} ${resultQueryCondition}
      ORDER BY ${escapeId('eventId')} ASC
      LIMIT ${+(skipCount * batchSize)}, ${+batchSize}`);

    for (const event of rows) {
      if (initialTimestamp == null) {
        initialTimestamp = event.timestamp;
      }

      if (countEvents++ > maxEventsByTimeframe && event.timestamp !== initialTimestamp) {
        break loop;
      }

      await callback(_objectSpread({}, event, {
        payload: JSON.parse(event.payload)
      }));
    }

    if (rows.length < batchSize) {
      break;
    }
  }
};

var _default = loadEvents;
exports.default = _default;
//# sourceMappingURL=load-events.js.map